@@ -1,6 +1,6 @@
 package Crypt::Bcrypt::Easy;
 {
-  $Crypt::Bcrypt::Easy::VERSION = '2.001003';
+  $Crypt::Bcrypt::Easy::VERSION = '2.002000';
 }
 use Carp;
 use strictures 1;
@@ -8,7 +8,7 @@ use App::bmkpasswd 'mkpasswd', 'passwdcmp';
 
 use Scalar::Util 'blessed';
 
-use Exporter 'import';
+use parent 'Exporter::Tiny';
 our @EXPORT = 'bcrypt';
 sub bcrypt {  Crypt::Bcrypt::Easy->new(@_)  }
 
@@ -94,6 +94,11 @@ directly).
 This POD briefly covers usage of this interface; 
 see L<App::bmkpasswd> for more details.
 
+This module uses L<Exporter::Tiny>; you can rename the L</bcrypt> function
+as-needed:
+
+  use Crypt::Bcrypt::Easy 'bcrypt' => { -as => 'bc' };
+
 =head2 bcrypt
 
   my $bcrypt = bcrypt( cost => '10' );
